import request from '@/utils/request'

// 查询公安治安处罚信息列表
export function listInformation(query) {
    return request({
        url: '/crmPublicSecurityPenaltyInformation/findByPage',
        method: 'get',
        params: query
    })
}

// 查询公安治安处罚信息详细
export function getInformation(id) {
    return request({
        url: '/crmPublicSecurityPenaltyInformation/' + id,
        method: 'get'
    })
}

// 新增公安治安处罚信息
export function addInformation(data) {
    return request({
        url: '/crmPublicSecurityPenaltyInformation',
        method: 'post',
        data: data
    })
}

// 修改公安治安处罚信息
export function updateInformation(data) {
    return request({
        url: '/crmPublicSecurityPenaltyInformation',
        method: 'put',
        data: data
    })
}

// 删除公安治安处罚信息
export function delInformation(id) {
    return request({
        url: '/crmPublicSecurityPenaltyInformation/deleteAll',
        method: 'delete'
    })
}
// 批量删除行政许可
export function delInformationBatch(ids) {
    console.log(ids);
    return request.post('/crmPublicSecurityPenaltyInformation/delete',ids)
}