<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryRef" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="统一社会信用代码" label-width="200" prop="unifiedSocialCreditCode">
        <el-input
            v-model="queryParams.unifiedSocialCreditCode"
            placeholder="请输入统一社会信用代码"
            clearable
            @keyup.enter="handleQuery"
        />
      </el-form-item>
<!--      <el-form-item label="注册号" prop="registrationNumber">-->
<!--        <el-input-->
<!--            v-model="queryParams.registrationNumber"-->
<!--            placeholder="请输入注册号"-->
<!--            clearable-->
<!--            @keyup.enter="handleQuery"-->
<!--        />-->
<!--      </el-form-item>-->
      <el-form-item label="企业名称" label-width="200" prop="enterpriseName">
        <el-input
            v-model="queryParams.enterpriseName"
            placeholder="请输入企业名称"
            clearable
            @keyup.enter="handleQuery"
        />
      </el-form-item>
<!--      <el-form-item label="登记类别" prop="registrationCategory">-->
<!--        <el-input-->
<!--            v-model="queryParams.registrationCategory"-->
<!--            placeholder="请输入登记类别"-->
<!--            clearable-->
<!--            @keyup.enter="handleQuery"-->
<!--        />-->
<!--      </el-form-item>-->
<!--      <el-form-item label="法定代表人/负责人姓名" prop="legalRepresentative">-->
<!--        <el-input-->
<!--            v-model="queryParams.legalRepresentative"-->
<!--            placeholder="请输入法定代表人/负责人姓名"-->
<!--            clearable-->
<!--            @keyup.enter="handleQuery"-->
<!--        />-->
<!--      </el-form-item>-->
<!--      <el-form-item label="法定代表人/负责人证件号码" prop="legalRepresentativeId">-->
<!--        <el-input-->
<!--            v-model="queryParams.legalRepresentativeId"-->
<!--            placeholder="请输入法定代表人/负责人证件号码"-->
<!--            clearable-->
<!--            @keyup.enter="handleQuery"-->
<!--        />-->
<!--      </el-form-item>-->
<!--      <el-form-item label="联络员姓名" prop="contactName">-->
<!--        <el-input-->
<!--            v-model="queryParams.contactName"-->
<!--            placeholder="请输入联络员姓名"-->
<!--            clearable-->
<!--            @keyup.enter="handleQuery"-->
<!--        />-->
<!--      </el-form-item>-->
<!--      <el-form-item label="联络员联系电话" prop="contactPhone">-->
<!--        <el-input-->
<!--            v-model="queryParams.contactPhone"-->
<!--            placeholder="请输入联络员联系电话"-->
<!--            clearable-->
<!--            @keyup.enter="handleQuery"-->
<!--        />-->
<!--      </el-form-item>-->
<!--      <el-form-item label="注册资本(万元)" prop="registeredCapital">-->
<!--        <el-input-->
<!--            v-model="queryParams.registeredCapital"-->
<!--            placeholder="请输入注册资本(万元)"-->
<!--            clearable-->
<!--            @keyup.enter="handleQuery"-->
<!--        />-->
<!--      </el-form-item>-->
<!--      <el-form-item label="实收资本(万元)" prop="paidInCapital">-->
<!--        <el-input-->
<!--            v-model="queryParams.paidInCapital"-->
<!--            placeholder="请输入实收资本(万元)"-->
<!--            clearable-->
<!--            @keyup.enter="handleQuery"-->
<!--        />-->
<!--      </el-form-item>-->
<!--      <el-form-item label="企业联系电话" prop="enterprisePhone">-->
<!--        <el-input-->
<!--            v-model="queryParams.enterprisePhone"-->
<!--            placeholder="请输入企业联系电话"-->
<!--            clearable-->
<!--            @keyup.enter="handleQuery"-->
<!--        />-->
<!--      </el-form-item>-->
<!--      <el-form-item label="成立日期" prop="establishmentDate">-->
<!--        <el-date-picker clearable-->
<!--                        v-model="queryParams.establishmentDate"-->
<!--                        type="date"-->
<!--                        value-format="YYYY-MM-DD"-->
<!--                        placeholder="请选择成立日期">-->
<!--        </el-date-picker>-->
<!--      </el-form-item>-->
<!--      <el-form-item label="营业期限" prop="businessPeriod">-->
<!--        <el-input-->
<!--            v-model="queryParams.businessPeriod"-->
<!--            placeholder="请输入营业期限"-->
<!--            clearable-->
<!--            @keyup.enter="handleQuery"-->
<!--        />-->
<!--      </el-form-item>-->
<!--      <el-form-item label="登记机关" prop="registrationAuthority">-->
<!--        <el-input-->
<!--            v-model="queryParams.registrationAuthority"-->
<!--            placeholder="请输入登记机关"-->
<!--            clearable-->
<!--            @keyup.enter="handleQuery"-->
<!--        />-->
<!--      </el-form-item>-->
<!--      <el-form-item label="邮政编号" prop="postalCode">-->
<!--        <el-input-->
<!--            v-model="queryParams.postalCode"-->
<!--            placeholder="请输入邮政编号"-->
<!--            clearable-->
<!--            @keyup.enter="handleQuery"-->
<!--        />-->
<!--      </el-form-item>-->
<!--      <el-form-item label="监管单位" prop="supervisoryAuthority">-->
<!--        <el-input-->
<!--            v-model="queryParams.supervisoryAuthority"-->
<!--            placeholder="请输入监管单位"-->
<!--            clearable-->
<!--            @keyup.enter="handleQuery"-->
<!--        />-->
<!--      </el-form-item>-->
<!--      <el-form-item label="行业代码" prop="industryCode">-->
<!--        <el-input-->
<!--            v-model="queryParams.industryCode"-->
<!--            placeholder="请输入行业代码"-->
<!--            clearable-->
<!--            @keyup.enter="handleQuery"-->
<!--        />-->
<!--      </el-form-item>-->
<!--      <el-form-item label="核准时间" prop="approvalTime">-->
<!--        <el-date-picker clearable-->
<!--                        v-model="queryParams.approvalTime"-->
<!--                        type="date"-->
<!--                        value-format="YYYY-MM-DD"-->
<!--                        placeholder="请选择核准时间">-->
<!--        </el-date-picker>-->
<!--      </el-form-item>-->
<!--      <el-form-item label="注销时间" prop="cancellationTime">-->
<!--        <el-date-picker clearable-->
<!--                        v-model="queryParams.cancellationTime"-->
<!--                        type="date"-->
<!--                        value-format="YYYY-MM-DD"-->
<!--                        placeholder="请选择注销时间">-->
<!--        </el-date-picker>-->
<!--      </el-form-item>-->
      <el-form-item>
        <el-button type="primary" icon="Search" @click="handleQuery">搜索</el-button>
        <el-button icon="Refresh" @click="resetQuery">重置</el-button>
      </el-form-item>
      <el-form-item>
        <el-row :gutter="10" class="mb8">
          <!--      <el-col :span="1.5">-->
          <!--        <el-button-->
          <!--            type="primary"-->
          <!--            plain-->
          <!--            icon="Plus"-->
          <!--            @click="handleAdd"-->
          <!--            v-hasPermi="['basicData:information:add']"-->
          <!--        >新增</el-button>-->
          <!--      </el-col>-->
          <!--      <el-col :span="1.5">-->
          <!--        <el-button-->
          <!--            type="success"-->
          <!--            plain-->
          <!--            icon="Edit"-->
          <!--            :disabled="single"-->
          <!--            @click="handleUpdate"-->
          <!--            v-hasPermi="['basicData:information:edit']"-->
          <!--        >修改</el-button>-->
          <!--      </el-col>-->
          <el-col :span="1.5">
            <el-popconfirm
                title="你确定清除所有数据？"
                confirm-button-text="是的"
                cancel-button-text="不是"
                :icon="InfoFilled"
                icon-color="#626AEF"
                @confirm="handleDelete"
            >
              <template #reference>
                <el-button
                    type="danger"
                    plain
                    icon="Delete"
                    v-hasPermi="['basicData:license:remove']"
                >清除全表</el-button>
              </template>
            </el-popconfirm>
          </el-col>
          <el-col :span="1.5">
            <el-button
                type="danger"
                plain
                icon="Delete"
                @click="batchDelete"
                v-hasPermi="['basicData:license:remove']"
                :disabled="ids.length === 0"
            >批量删除</el-button>
          </el-col>
          <el-col :span="1.5">
            <el-button
                type="warning"
                plain
                icon="Download"
                :disabled="!informationList.length"
                @click="handleExport"
                v-hasPermi="['basicData:information:export']"
            >导出</el-button>
          </el-col>
          <el-col :span="1.5">
            <el-button type="info" plain icon="Upload" @click="handleImport"
                       v-hasPermi="['system:user:import']">导入
            </el-button>
          </el-col>
          <el-col :span="1.5">
            <el-button type="success" plain icon="Download" @click="downloadTemplate">
              下载导入模版
            </el-button>
          </el-col>
          <!--      <right-toolbar v-model:showSearch="showSearch" @queryTable="getList"></right-toolbar>-->
        </el-row>
      </el-form-item>
    </el-form>


    <el-table v-loading="loading" :data="informationList" height="650" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
<!--      <el-table-column label="主键" align="center" prop="id" />-->
      <el-table-column label="统一社会信用代码" align="center" prop="unifiedSocialCreditCode" width="200" />
      <el-table-column label="登记类别" align="center" prop="registrationCategory" :show-overflow-tooltip="true" />
      <el-table-column label="企业类型" align="center" prop="enterpriseType" :show-overflow-tooltip="true" />
      <el-table-column label="法定代表人/负责人姓名" align="center" prop="legalRepresentative" :show-overflow-tooltip="true" />
      <el-table-column label="法定代表人/负责人证件号码" align="center" prop="legalRepresentativeId" :show-overflow-tooltip="true" />
      <el-table-column label="联络员姓名" align="center" prop="contactName" :show-overflow-tooltip="true" />
      <el-table-column label="联络员联系电话" align="center" prop="contactPhone" :show-overflow-tooltip="true" />
      <el-table-column label="注册资本(万元)" align="center" prop="registeredCapital" :show-overflow-tooltip="true" />
      <el-table-column label="实收资本(万元)" align="center" prop="paidInCapital" :show-overflow-tooltip="true" />
      <el-table-column label="企业联系电话" align="center" prop="enterprisePhone" :show-overflow-tooltip="true" />
      <el-table-column label="经营范围" align="center" prop="businessScope" :show-overflow-tooltip="true" />
      <el-table-column label="成立日期" align="center" prop="establishmentDate" :show-overflow-tooltip="true" />
      <el-table-column label="营业期限" align="center" prop="businessPeriod" :show-overflow-tooltip="true" />
      <el-table-column label="登记机关" align="center" prop="registrationAuthority" :show-overflow-tooltip="true" />
      <el-table-column label="邮政编号" align="center" prop="postalCode" :show-overflow-tooltip="true" />
      <el-table-column label="住所" align="center" prop="address" :show-overflow-tooltip="true" />
      <el-table-column label="监管单位" align="center" prop="supervisoryAuthority" :show-overflow-tooltip="true" />
      <el-table-column label="状态" align="center" prop="status" :show-overflow-tooltip="true" />
      <el-table-column label="行业代码" align="center" prop="industryCode" :show-overflow-tooltip="true" />
      <el-table-column label="核准时间" align="center" prop="approvalTime" :show-overflow-tooltip="true" />
      <el-table-column label="注销时间" align="center" prop="cancellationTime" :show-overflow-tooltip="true" />
<!--      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">-->
<!--        <template #default="scope">-->
<!--          <el-button-->
<!--              type="text"-->
<!--              icon="Edit"-->
<!--              @click="handleUpdate(scope.row)"-->
<!--              v-hasPermi="['basicData:information:edit']"-->
<!--          >修改</el-button>-->
<!--          <el-button-->
<!--              type="text"-->
<!--              icon="Delete"-->
<!--              @click="handleDelete(scope.row)"-->
<!--              v-hasPermi="['basicData:information:remove']"-->
<!--          >删除</el-button>-->
<!--        </template>-->
<!--      </el-table-column>-->
    </el-table>

    <div style="position: fixed;bottom: 20px;right: 10px;">
      <pagination
          v-show="total>0"
          :total="total"
          v-model:page="queryParams.pageNum"
          v-model:limit="queryParams.pageSize"
          @pagination="getList"
      />
    </div>

    <el-dialog :title="upload.title" v-model="upload.open" width="400px" append-to-body>
      <el-upload ref="uploadRef" :limit="1" accept=".xlsx, .xls" :headers="upload.headers"
                 :action="upload.url + '?updateSupport=' + upload.updateSupport" :disabled="upload.isUploading"
                 :on-progress="handleFileUploadProgress" :on-success="handleFileSuccess" :auto-upload="false" drag>
        <el-icon class="el-icon--upload"><upload-filled /></el-icon>
        <div class="el-upload__text">将文件拖到此处，或<em>点击上传</em></div>
        <template #tip>
          <div class="el-upload__tip text-center">
            <span>仅允许导入xls、xlsx格式文件。</span>
          </div>
        </template>
      </el-upload>
      <template #footer>
        <div class="dialog-footer">
          <el-button type="primary" @click="submitFileForm">确 定</el-button>
          <el-button @click="upload.open = false">取 消</el-button>
        </div>
      </template>
    </el-dialog>

    <!-- 添加或修改营业执照信息对话框 -->
  </div>
</template>

<script setup name="Information">
import {
  listInformation,
  getInformation,
  delInformation,
  addInformation,
  updateInformation,
  delInformationBatch
} from "@/api/basicData/information7";
import {reactive} from "vue";
import {getToken} from "@/utils/auth";
import {ElMessage} from "element-plus";
import {likeQueryMethod} from "@/utils/likeQueryMethod";

const { proxy } = getCurrentInstance();

const informationList = ref([]);
const open = ref(false);
const loading = ref(true);
const showSearch = ref(true);
const ids = ref([]);
const single = ref(true);
const multiple = ref(true);
const total = ref(0);
const title = ref("");

const upload = reactive({
  // 是否显示弹出层（用户导入）
  open: false,
  // 弹出层标题（用户导入）
  title: '',
  // 是否禁用上传
  isUploading: false,
  // 设置上传的请求头部
  headers: {Authorization: getToken()},
  // 上传的地址
  url: import.meta.env.VITE_APP_BASE_API + '/crmBusinessLicenseInformation/importData'
})
const handleFileSuccess = (e)=>{
  if(e.code == 200){
    ElMessage({
      type:"success",
      message:e.msg
    })
    getList()
    proxy.$refs['uploadRef']?.clearFiles()
  }else {
    ElMessage({
      type:"error",
      message:e.msg
    })
    proxy.$refs['uploadRef']?.clearFiles()
  }
}
function submitFileForm() {
  proxy.$refs['uploadRef'].submit()
  upload.open = false;
  // setTimeout(getList,1000)
}
function handleImport() {
  upload.open = true
  // let toServerObj = likeQueryMethod('unified_social_credit_code', queryParams.value.unifiedSocialCreditCode, queryParams.value.pageNum, queryParams.value.pageSize,"enterprise_name",queryParams.value.enterpriseName);
  // listInformation(toServerObj).then(res=>{
  //   if(res.records.length >0){
  //     ElMessage({
  //       type:'warning',
  //       message:'当前已经有数据，请删除后再导入'
  //     })
  //     return
  //   }else {
  //     upload.title = '用户导入'
  //     upload.open = true
  //   }
  // })
}

const data = reactive({
  form: {},
  queryParams: {
    pageNum: 1,
    pageSize: 20,
    enterpriseName: null,
    unifiedSocialCreditCode: '',
    registrationCategory: null,
    enterpriseType: null,
    legalRepresentative: null,
    legalRepresentativeId: null,
    contactName: null,
    contactPhone: null,
    registeredCapital: null,
    paidInCapital: null,
    enterprisePhone: null,
    businessScope: null,
    establishmentDate: null,
    businessPeriod: null,
    registrationAuthority: null,
    postalCode: null,
    address: null,
    supervisoryAuthority: null,
    status: null,
    industryCode: null,
    approvalTime: null,
    cancellationTime: null,
  },
  rules: {
  }
});

const { queryParams, form, rules } = toRefs(data);

/** 查询营业执照信息列表 */
function getList() {
  loading.value = true;
  let toServerObj = likeQueryMethod('unified_social_credit_code', queryParams.value.unifiedSocialCreditCode, queryParams.value.pageNum, queryParams.value.pageSize,"enterprise_name",queryParams.value.enterpriseName);
  listInformation(toServerObj).then(response => {
    informationList.value = response.records;
    total.value = response.total;
    loading.value = false;
  });
}

// 取消按钮
function cancel() {
  open.value = false;
  reset();
}

// 表单重置
function reset() {
  form.value = {
    id: null,
    enterpriseName: null,
    unifiedSocialCreditCode: null,
    registrationCategory: null,
    enterpriseType: null,
    legalRepresentative: null,
    legalRepresentativeId: null,
    contactName: null,
    contactPhone: null,
    registeredCapital: null,
    paidInCapital: null,
    enterprisePhone: null,
    businessScope: null,
    establishmentDate: null,
    businessPeriod: null,
    registrationAuthority: null,
    postalCode: null,
    address: null,
    supervisoryAuthority: null,
    status: "0",
    industryCode: null,
    approvalTime: null,
    cancellationTime: null,
    createTime: null,
    updateTime: null
  };
  proxy.resetForm("informationRef");
}

/** 搜索按钮操作 */
function handleQuery() {
  queryParams.value.pageNum = 1;
  getList();
}

/** 重置按钮操作 */
function resetQuery() {
  proxy.resetForm("queryRef");
  handleQuery();
}

// 多选框选中数据
function handleSelectionChange(selection) {
  ids.value = selection.map(item => item.id);
  single.value = selection.length != 1;
  multiple.value = !selection.length;
}

/** 新增按钮操作 */
function handleAdd() {
  reset();
  open.value = true;
  title.value = "添加营业执照信息";
}

/** 修改按钮操作 */
function handleUpdate(row) {
  reset();
  const id = row.id || ids.value
  getInformation(id).then(response => {
    form.value = response.data;
    open.value = true;
    title.value = "修改营业执照信息";
  });
}

/** 提交按钮 */
function submitForm() {
  proxy.$refs["informationRef"].validate(valid => {
    if (valid) {
      if (form.value.id != null) {
        updateInformation(form.value).then(response => {
          proxy.$modal.msgSuccess("修改成功");
          open.value = false;
          getList();
        });
      } else {
        addInformation(form.value).then(response => {
          proxy.$modal.msgSuccess("新增成功");
          open.value = false;
          getList();
        });
      }
    }
  });
}

/** 删除按钮操作 */
async function handleDelete(row) {
  const res = await delInformation();
  if(res.code == 200){
    ElMessage({
      type:'success',
      message:'删除成功'
    })
    getList();
  }
  // const ids = row.id || ids.value;
  // proxy.$modal.confirm('是否确认删除营业执照信息编号为"' + ids + '"的数据项？').then(function() {
  //   return delInformation(ids);
  // }).then(() => {
  //   getList();
  //   proxy.$modal.msgSuccess("删除成功");
  // }).catch(() => {});
}
/**
 * 批量删除
 */
const batchDelete = (row)=>{
  const idsToS = row.id || ids.value;
  proxy.$modal.confirm('是否确认删除这'+idsToS.length+'条的数据项？').then(function() {
    return delInformationBatch(toRaw(idsToS));
  }).then(() => {
    getList();
    proxy.$modal.msgSuccess("删除成功");
  }).catch(() => {});
}

/** 导出按钮操作 */
function handleExport() {
  proxy.download('crmBusinessLicenseInformation/exportData', {
    ...queryParams.value
  }, `营业执照信息_${new Date().getTime()}.xlsx`)
}
const downloadTemplate = ()=>{
  proxy.download('crmBusinessLicenseInformation/getUploadTemplate',{}, `营业执照信息模板.xlsx`)
}

getList();
</script>
